( function( wp ) {
    const { registerBlockType } = wp.blocks;
    const { InspectorControls, useBlockProps, PanelColorSettings } = wp.blockEditor;
    const { PanelBody, SelectControl } = wp.components;
    const { __ } = wp.i18n;

    registerBlockType( 'quest-web-launch/block', {
        title: 'Quest Web Launch',
        icon: 'external',
        category: 'widgets',
        attributes: {
            buttonSize: {
                type: 'string',
                default: 'medium',
            },
            fontStyle: {
                type: 'string',
                default: 'normal',
            },
            fontSize: {
                type: 'string',
                default: 'medium',
            },
            buttonColor: {
                type: 'string',
                default: '#005185', // Meta's blue
            },
            fontColor: {
                type: 'string',
                default: '#ffffff', // White
            },
        },
        edit: function( props ) {
            const { attributes, setAttributes } = props;
            const { buttonSize, fontStyle, fontSize, buttonColor, fontColor } = attributes;

            const blockProps = useBlockProps({
                className: 'quest-web-launch-button',
            });

            return [
                wp.element.createElement(
                    InspectorControls,
                    {},
                    wp.element.createElement(
                        PanelBody,
                        { title: __( 'Button Settings' ) },
                        wp.element.createElement(
                            SelectControl,
                            {
                                label: __( 'Button Size' ),
                                value: buttonSize,
                                options: [
                                    { value: 'tiny', label: __( 'Tiny' ) },
                                    { value: 'extra-small', label: __( 'Extra Small' ) },
                                    { value: 'small', label: __( 'Small' ) },
                                    { value: 'medium-small', label: __( 'Medium Small' ) },
                                    { value: 'medium', label: __( 'Medium' ) },
                                    { value: 'medium-large', label: __( 'Medium Large' ) },
                                    { value: 'large', label: __( 'Large' ) },
                                    { value: 'extra-large', label: __( 'Extra Large' ) },
                                    { value: 'huge', label: __( 'Huge' ) },
                                ],
                                onChange: ( value ) => setAttributes( { buttonSize: value } ),
                            }
                        ),
                        wp.element.createElement(
                            SelectControl,
                            {
                                label: __( 'Font Style' ),
                                value: fontStyle,
                                options: [
                                    { value: 'normal', label: __( 'Normal' ) },
                                    { value: 'italic', label: __( 'Italic' ) },
                                    { value: 'bold', label: __( 'Bold' ) },
                                ],
                                onChange: ( value ) => setAttributes( { fontStyle: value } ),
                            }
                        ),
                        wp.element.createElement(
                            SelectControl,
                            {
                                label: __( 'Font Size' ),
                                value: fontSize,
                                options: [
                                    { value: 'tiny', label: __( 'Tiny (10px)' ) },
                                    { value: 'extra-small', label: __( 'Extra Small (12px)' ) },
                                    { value: 'small', label: __( 'Small (14px)' ) },
                                    { value: 'medium-small', label: __( 'Medium Small (15px)' ) },
                                    { value: 'medium', label: __( 'Medium (16px)' ) },
                                    { value: 'medium-large', label: __( 'Medium Large (17px)' ) },
                                    { value: 'large', label: __( 'Large (18px)' ) },
                                    { value: 'extra-large', label: __( 'Extra Large (20px)' ) },
                                    { value: 'huge', label: __( 'Huge (22px)' ) },
                                ],
                                onChange: ( value ) => setAttributes( { fontSize: value } ),
                            }
                        )
                    ),
                    wp.element.createElement(
                        PanelColorSettings,
                        {
                            title: __( 'Color Settings' ),
                            initialOpen: false,
                            colorSettings: [
                                {
                                    value: buttonColor,
                                    onChange: ( value ) => setAttributes( { buttonColor: value || '#005185' } ),
                                    label: __( 'Button Background Color' ),
                                    enableAlpha: true,
                                },
                                {
                                    value: fontColor,
                                    onChange: ( value ) => setAttributes( { fontColor: value || '#ffffff' } ),
                                    label: __( 'Font Color' ),
                                    enableAlpha: true,
                                },
                            ],
                        }
                    )
                ),
                wp.element.createElement(
                    'div',
                    blockProps,
                    wp.element.createElement(
                        'a',
                        {
                            href: '#',
                            className: `quest-web-launch-button__link button-size-${buttonSize} font-style-${fontStyle} font-size-${fontSize}`,
                            style: {
                                backgroundColor: buttonColor,
                                color: fontColor,
                                pointerEvents: 'none',
                            },
                        },
                        'Open this page on your Quest VR Headset'
                    )
                ),
            ];
        },
        save: function() {
            // Dynamic block, no save output needed
            return null;
        },
    } );
} )( window.wp );