<?php
/**
 * Plugin Name: Quest Web Launch Block
 * Description: A Gutenberg block to open the current page on a Meta Quest VR headset with customizable button size, font style, font size, button color, and font color, with links opening in a new window.
 * Version: 1.4.0
 * Author: Your Name
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

function quest_web_launch_block_register() {
    // Register block script
    wp_register_script(
        'quest-web-launch-block',
        plugins_url( 'block.js', __FILE__ ),
        array( 'wp-blocks', 'wp-element', 'wp-editor', 'wp-components', 'wp-color-picker' ),
        '1.4.0',
        true
    );

    // Register block style
    wp_register_style(
        'quest-web-launch-block-style',
        plugins_url( 'style.css', __FILE__ ),
        array(),
        '1.4.0'
    );

    // Register the block
    register_block_type( 'quest-web-launch/block', array(
        'editor_script' => 'quest-web-launch-block',
        'style' => 'quest-web-launch-block-style',
        'attributes' => array(
            'buttonSize' => array(
                'type' => 'string',
                'default' => 'medium',
            ),
            'fontStyle' => array(
                'type' => 'string',
                'default' => 'normal',
            ),
            'fontSize' => array(
                'type' => 'string',
                'default' => 'medium',
            ),
            'buttonColor' => array(
                'type' => 'string',
                'default' => '#005185', // Meta's blue
            ),
            'fontColor' => array(
                'type' => 'string',
                'default' => '#ffffff', // White
            ),
        ),
        'render_callback' => 'quest_web_launch_block_render',
    ) );
}
add_action( 'init', 'quest_web_launch_block_register' );

function quest_web_launch_block_render( $attributes ) {
    // Get the current page URL
    $current_url = home_url( add_query_arg( array() ) );
    
    // URL-encode the current URL
    $encoded_url = urlencode( $current_url );
    
    // Construct the Quest Web Launch URL
    $quest_url = 'https://www.oculus.com/open_url/?url=' . $encoded_url;

    // Get attributes with defaults
    $button_size = isset( $attributes['buttonSize'] ) ? sanitize_text_field( $attributes['buttonSize'] ) : 'medium';
    $font_style = isset( $attributes['fontStyle'] ) ? sanitize_text_field( $attributes['fontStyle'] ) : 'normal';
    $font_size = isset( $attributes['fontSize'] ) ? sanitize_text_field( $attributes['fontSize'] ) : 'medium';
    $button_color = isset( $attributes['buttonColor'] ) ? sanitize_hex_color( $attributes['buttonColor'] ) : '#005185';
    $font_color = isset( $attributes['fontColor'] ) ? sanitize_hex_color( $attributes['fontColor'] ) : '#ffffff';

    // Map attributes to CSS classes
    $button_class = 'quest-web-launch-button__link';
    $button_class .= ' button-size-' . $button_size;
    $button_class .= ' font-style-' . $font_style;
    $button_class .= ' font-size-' . $font_size;

    // Inline styles for colors
    $inline_style = 'background-color: ' . esc_attr( $button_color ) . '; color: ' . esc_attr( $font_color ) . ';';

    // Output the button with target="_blank" and rel="noopener"
    $output = '<div class="wp-block-quest-web-launch-block quest-web-launch-button">';
    $output .= '<a href="' . esc_url( $quest_url ) . '" class="' . esc_attr( $button_class ) . '" style="' . $inline_style . '" target="_blank" rel="noopener">';
    $output .= esc_html__( 'Open this page on your Quest VR Headset', 'quest-web-launch' );
    $output .= '</a>';
    $output .= '</div>';

    return $output;
}